{% extends "base.html" %}
{% block title %}{{ error_title|default("Error") }} — Shoreguard{% endblock %}

{% block breadcrumbs %}
<ol class="breadcrumb mb-0">
    <li class="breadcrumb-item active">{{ error_title|default("Error") }}</li>
</ol>
{% endblock %}

{% block content %}
<div class="text-center py-5">
    <i class="bi bi-{{ error_icon|default('exclamation-triangle') }} fs-1 d-block mb-3 text-warning"></i>
    <h4>{{ error_title|default("Something went wrong") }}</h4>
    <p class="text-muted mb-4">{{ error_message|default("An unexpected error occurred.") }}</p>
    <a href="/" class="btn btn-outline-secondary btn-sm">
        <i class="bi bi-house me-1"></i>Back to Dashboard
    </a>
</div>
{% endblock %}
