<div class="modal fade" id="confirmModal" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered modal-sm">
        <div class="modal-content sg-modal-themed">
            <div class="modal-body text-center py-4">
                <i id="confirm-icon" class="bi bi-exclamation-triangle fs-1 text-warning d-block mb-3"></i>
                <p id="confirm-message" class="mb-0"></p>
            </div>
            <div class="modal-footer border-0 justify-content-center">
                <button class="btn btn-outline-secondary btn-sm" data-bs-dismiss="modal">Cancel</button>
                <button class="btn btn-danger btn-sm" id="confirm-action">Confirm</button>
            </div>
        </div>
    </div>
</div>
