# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: inference.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "inference.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0finference.proto\x12\x16openshell.inference.v1"W\n\x16\x43lusterInferenceConfig\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x14\n\x0ctimeout_secs\x18\x03 \x01(\x04"{\n\x0eInferenceRoute\x12\n\n\x02id\x18\x01 \x01(\t\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..openshell.inference.v1.ClusterInferenceConfig\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x04"\x92\x01\n\x1aSetClusterInferenceRequest\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t\x12\x0e\n\x06verify\x18\x04 \x01(\x08\x12\x11\n\tno_verify\x18\x05 \x01(\x08\x12\x14\n\x0ctimeout_secs\x18\x06 \x01(\x04"2\n\x11ValidatedEndpoint\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t"\xe7\x01\n\x1bSetClusterInferenceResponse\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x04\x12\x12\n\nroute_name\x18\x04 \x01(\t\x12\x1c\n\x14validation_performed\x18\x05 \x01(\x08\x12\x46\n\x13validated_endpoints\x18\x06 \x03(\x0b\x32).openshell.inference.v1.ValidatedEndpoint\x12\x14\n\x0ctimeout_secs\x18\x07 \x01(\x04"0\n\x1aGetClusterInferenceRequest\x12\x12\n\nroute_name\x18\x01 \x01(\t"\x81\x01\n\x1bGetClusterInferenceResponse\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x04\x12\x12\n\nroute_name\x18\x04 \x01(\t\x12\x14\n\x0ctimeout_secs\x18\x05 \x01(\x04"\x1b\n\x19GetInferenceBundleRequest"\x92\x01\n\rResolvedRoute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x11\n\tprotocols\x18\x03 \x03(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x10\n\x08model_id\x18\x05 \x01(\t\x12\x15\n\rprovider_type\x18\x06 \x01(\t\x12\x14\n\x0ctimeout_secs\x18\x07 \x01(\x04"~\n\x1aGetInferenceBundleResponse\x12\x35\n\x06routes\x18\x01 \x03(\x0b\x32%.openshell.inference.v1.ResolvedRoute\x12\x10\n\x08revision\x18\x02 \x01(\t\x12\x17\n\x0fgenerated_at_ms\x18\x03 \x01(\x03\x32\x88\x03\n\tInference\x12{\n\x12GetInferenceBundle\x12\x31.openshell.inference.v1.GetInferenceBundleRequest\x1a\x32.openshell.inference.v1.GetInferenceBundleResponse\x12~\n\x13SetClusterInference\x12\x32.openshell.inference.v1.SetClusterInferenceRequest\x1a\x33.openshell.inference.v1.SetClusterInferenceResponse\x12~\n\x13GetClusterInference\x12\x32.openshell.inference.v1.GetClusterInferenceRequest\x1a\x33.openshell.inference.v1.GetClusterInferenceResponseB(\n$com.anthropic.openshell.inference.v1P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "inference_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\n$com.anthropic.openshell.inference.v1P\001"
    _globals["_CLUSTERINFERENCECONFIG"]._serialized_start = 43
    _globals["_CLUSTERINFERENCECONFIG"]._serialized_end = 130
    _globals["_INFERENCEROUTE"]._serialized_start = 132
    _globals["_INFERENCEROUTE"]._serialized_end = 255
    _globals["_SETCLUSTERINFERENCEREQUEST"]._serialized_start = 258
    _globals["_SETCLUSTERINFERENCEREQUEST"]._serialized_end = 404
    _globals["_VALIDATEDENDPOINT"]._serialized_start = 406
    _globals["_VALIDATEDENDPOINT"]._serialized_end = 456
    _globals["_SETCLUSTERINFERENCERESPONSE"]._serialized_start = 459
    _globals["_SETCLUSTERINFERENCERESPONSE"]._serialized_end = 690
    _globals["_GETCLUSTERINFERENCEREQUEST"]._serialized_start = 692
    _globals["_GETCLUSTERINFERENCEREQUEST"]._serialized_end = 740
    _globals["_GETCLUSTERINFERENCERESPONSE"]._serialized_start = 743
    _globals["_GETCLUSTERINFERENCERESPONSE"]._serialized_end = 872
    _globals["_GETINFERENCEBUNDLEREQUEST"]._serialized_start = 874
    _globals["_GETINFERENCEBUNDLEREQUEST"]._serialized_end = 901
    _globals["_RESOLVEDROUTE"]._serialized_start = 904
    _globals["_RESOLVEDROUTE"]._serialized_end = 1050
    _globals["_GETINFERENCEBUNDLERESPONSE"]._serialized_start = 1052
    _globals["_GETINFERENCEBUNDLERESPONSE"]._serialized_end = 1178
    _globals["_INFERENCE"]._serialized_start = 1181
    _globals["_INFERENCE"]._serialized_end = 1573
# @@protoc_insertion_point(module_scope)
