# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: openshell.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "openshell.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import datamodel_pb2 as datamodel__pb2
from . import sandbox_pb2 as sandbox__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fopenshell.proto\x12\x0copenshell.v1\x1a\x0f\x64\x61tamodel.proto\x1a\rsandbox.proto"\x0f\n\rHealthRequest"N\n\x0eHealthResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.openshell.v1.ServiceStatus\x12\x0f\n\x07version\x18\x02 \x01(\t"W\n\x14\x43reateSandboxRequest\x12\x31\n\x04spec\x18\x01 \x01(\x0b\x32#.openshell.datamodel.v1.SandboxSpec\x12\x0c\n\x04name\x18\x02 \x01(\t"!\n\x11GetSandboxRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"5\n\x14ListSandboxesRequest\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r"$\n\x14\x44\x65leteSandboxRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"C\n\x0fSandboxResponse\x12\x30\n\x07sandbox\x18\x01 \x01(\x0b\x32\x1f.openshell.datamodel.v1.Sandbox"K\n\x15ListSandboxesResponse\x12\x32\n\tsandboxes\x18\x01 \x03(\x0b\x32\x1f.openshell.datamodel.v1.Sandbox"(\n\x15\x44\x65leteSandboxResponse\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08"-\n\x17\x43reateSshSessionRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t"\xcc\x01\n\x18\x43reateSshSessionResponse\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0cgateway_host\x18\x03 \x01(\t\x12\x14\n\x0cgateway_port\x18\x04 \x01(\r\x12\x16\n\x0egateway_scheme\x18\x05 \x01(\t\x12\x14\n\x0c\x63onnect_path\x18\x06 \x01(\t\x12\x1c\n\x14host_key_fingerprint\x18\x07 \x01(\t\x12\x15\n\rexpires_at_ms\x18\x08 \x01(\x03"(\n\x17RevokeSshSessionRequest\x12\r\n\x05token\x18\x01 \x01(\t"+\n\x18RevokeSshSessionResponse\x12\x0f\n\x07revoked\x18\x01 \x01(\x08"\xee\x01\n\x12\x45xecSandboxRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x0f\n\x07workdir\x18\x03 \x01(\t\x12\x46\n\x0b\x65nvironment\x18\x04 \x03(\x0b\x32\x31.openshell.v1.ExecSandboxRequest.EnvironmentEntry\x12\x17\n\x0ftimeout_seconds\x18\x05 \x01(\r\x12\r\n\x05stdin\x18\x06 \x01(\x0c\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"!\n\x11\x45xecSandboxStdout\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"!\n\x11\x45xecSandboxStderr\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"$\n\x0f\x45xecSandboxExit\x12\x11\n\texit_code\x18\x01 \x01(\x05"\xb2\x01\n\x10\x45xecSandboxEvent\x12\x31\n\x06stdout\x18\x01 \x01(\x0b\x32\x1f.openshell.v1.ExecSandboxStdoutH\x00\x12\x31\n\x06stderr\x18\x02 \x01(\x0b\x32\x1f.openshell.v1.ExecSandboxStderrH\x00\x12-\n\x04\x65xit\x18\x03 \x01(\x0b\x32\x1d.openshell.v1.ExecSandboxExitH\x00\x42\t\n\x07payload"\x88\x01\n\nSshSession\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsandbox_id\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x15\n\rcreated_at_ms\x18\x04 \x01(\x03\x12\x0f\n\x07revoked\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x15\n\rexpires_at_ms\x18\x07 \x01(\x03"\xec\x01\n\x13WatchSandboxRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rfollow_status\x18\x02 \x01(\x08\x12\x13\n\x0b\x66ollow_logs\x18\x03 \x01(\x08\x12\x15\n\rfollow_events\x18\x04 \x01(\x08\x12\x16\n\x0elog_tail_lines\x18\x05 \x01(\r\x12\x12\n\nevent_tail\x18\x06 \x01(\r\x12\x18\n\x10stop_on_terminal\x18\x07 \x01(\x08\x12\x14\n\x0clog_since_ms\x18\x08 \x01(\x03\x12\x13\n\x0blog_sources\x18\t \x03(\t\x12\x15\n\rlog_min_level\x18\n \x01(\t"\xa5\x02\n\x12SandboxStreamEvent\x12\x32\n\x07sandbox\x18\x01 \x01(\x0b\x32\x1f.openshell.datamodel.v1.SandboxH\x00\x12+\n\x03log\x18\x02 \x01(\x0b\x32\x1c.openshell.v1.SandboxLogLineH\x00\x12,\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1b.openshell.v1.PlatformEventH\x00\x12\x35\n\x07warning\x18\x04 \x01(\x0b\x32".openshell.v1.SandboxStreamWarningH\x00\x12>\n\x13\x64raft_policy_update\x18\x05 \x01(\x0b\x32\x1f.openshell.v1.DraftPolicyUpdateH\x00\x42\t\n\x07payload"\xe3\x01\n\x0eSandboxLogLine\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\x14\n\x0ctimestamp_ms\x18\x02 \x01(\x03\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\x06 \x01(\t\x12\x38\n\x06\x66ields\x18\x07 \x03(\x0b\x32(.openshell.v1.SandboxLogLine.FieldsEntry\x1a-\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xd2\x01\n\rPlatformEvent\x12\x14\n\x0ctimestamp_ms\x18\x01 \x01(\x03\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12;\n\x08metadata\x18\x06 \x03(\x0b\x32).openshell.v1.PlatformEvent.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\'\n\x14SandboxStreamWarning\x12\x0f\n\x07message\x18\x01 \x01(\t"K\n\x15\x43reateProviderRequest\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .openshell.datamodel.v1.Provider""\n\x12GetProviderRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"5\n\x14ListProvidersRequest\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r"K\n\x15UpdateProviderRequest\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .openshell.datamodel.v1.Provider"%\n\x15\x44\x65leteProviderRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"F\n\x10ProviderResponse\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .openshell.datamodel.v1.Provider"L\n\x15ListProvidersResponse\x12\x33\n\tproviders\x18\x01 \x03(\x0b\x32 .openshell.datamodel.v1.Provider")\n\x16\x44\x65leteProviderResponse\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08":\n$GetSandboxProviderEnvironmentRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t"\xb6\x01\n%GetSandboxProviderEnvironmentResponse\x12Y\n\x0b\x65nvironment\x18\x01 \x03(\x0b\x32\x44.openshell.v1.GetSandboxProviderEnvironmentResponse.EnvironmentEntry\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xd0\x01\n\x13UpdateConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\x06policy\x18\x02 \x01(\x0b\x32#.openshell.sandbox.v1.SandboxPolicy\x12\x13\n\x0bsetting_key\x18\x03 \x01(\t\x12\x39\n\rsetting_value\x18\x04 \x01(\x0b\x32".openshell.sandbox.v1.SettingValue\x12\x16\n\x0e\x64\x65lete_setting\x18\x05 \x01(\x08\x12\x0e\n\x06global\x18\x06 \x01(\x08"h\n\x14UpdateConfigResponse\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x13\n\x0bpolicy_hash\x18\x02 \x01(\t\x12\x19\n\x11settings_revision\x18\x03 \x01(\x04\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08"N\n\x1dGetSandboxPolicyStatusRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x0e\n\x06global\x18\x03 \x01(\x08"o\n\x1eGetSandboxPolicyStatusResponse\x12\x35\n\x08revision\x18\x01 \x01(\x0b\x32#.openshell.v1.SandboxPolicyRevision\x12\x16\n\x0e\x61\x63tive_version\x18\x02 \x01(\r"Y\n\x1aListSandboxPoliciesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\r\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12\x0e\n\x06global\x18\x04 \x01(\x08"U\n\x1bListSandboxPoliciesResponse\x12\x36\n\trevisions\x18\x01 \x03(\x0b\x32#.openshell.v1.SandboxPolicyRevision"\x80\x01\n\x19ReportPolicyStatusRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12*\n\x06status\x18\x03 \x01(\x0e\x32\x1a.openshell.v1.PolicyStatus\x12\x12\n\nload_error\x18\x04 \x01(\t"\x1c\n\x1aReportPolicyStatusResponse"\xdf\x01\n\x15SandboxPolicyRevision\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x13\n\x0bpolicy_hash\x18\x02 \x01(\t\x12*\n\x06status\x18\x03 \x01(\x0e\x32\x1a.openshell.v1.PolicyStatus\x12\x12\n\nload_error\x18\x04 \x01(\t\x12\x15\n\rcreated_at_ms\x18\x05 \x01(\x03\x12\x14\n\x0cloaded_at_ms\x18\x06 \x01(\x03\x12\x33\n\x06policy\x18\x07 \x01(\x0b\x32#.openshell.sandbox.v1.SandboxPolicy"p\n\x15GetSandboxLogsRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\r\n\x05lines\x18\x02 \x01(\r\x12\x10\n\x08since_ms\x18\x03 \x01(\x03\x12\x0f\n\x07sources\x18\x04 \x03(\t\x12\x11\n\tmin_level\x18\x05 \x01(\t"X\n\x16PushSandboxLogsRequest\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12*\n\x04logs\x18\x02 \x03(\x0b\x32\x1c.openshell.v1.SandboxLogLine"\x19\n\x17PushSandboxLogsResponse"Z\n\x16GetSandboxLogsResponse\x12*\n\x04logs\x18\x01 \x03(\x0b\x32\x1c.openshell.v1.SandboxLogLine\x12\x14\n\x0c\x62uffer_total\x18\x02 \x01(\r"P\n\x0fL7RequestSample\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x63ision\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r"\x95\x03\n\rDenialSummary\x12\x12\n\nsandbox_id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x0e\n\x06\x62inary\x18\x04 \x01(\t\x12\x11\n\tancestors\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65ny_reason\x18\x06 \x01(\t\x12\x15\n\rfirst_seen_ms\x18\x07 \x01(\x03\x12\x14\n\x0clast_seen_ms\x18\x08 \x01(\x03\x12\r\n\x05\x63ount\x18\t \x01(\r\x12\x18\n\x10suppressed_count\x18\n \x01(\r\x12\x13\n\x0btotal_count\x18\x0b \x01(\r\x12\x17\n\x0fsample_cmdlines\x18\x0c \x03(\t\x12\x15\n\rbinary_sha256\x18\r \x01(\t\x12\x12\n\npersistent\x18\x0e \x01(\x08\x12\x14\n\x0c\x64\x65nial_stage\x18\x0f \x01(\t\x12\x39\n\x12l7_request_samples\x18\x10 \x03(\x0b\x32\x1d.openshell.v1.L7RequestSample\x12\x1c\n\x14l7_inspection_active\x18\x11 \x01(\x08"\x81\x03\n\x0bPolicyChunk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x11\n\trule_name\x18\x03 \x01(\t\x12>\n\rproposed_rule\x18\x04 \x01(\x0b\x32\'.openshell.sandbox.v1.NetworkPolicyRule\x12\x11\n\trationale\x18\x05 \x01(\t\x12\x16\n\x0esecurity_notes\x18\x06 \x01(\t\x12\x12\n\nconfidence\x18\x07 \x01(\x02\x12\x1a\n\x12\x64\x65nial_summary_ids\x18\x08 \x03(\t\x12\x15\n\rcreated_at_ms\x18\t \x01(\x03\x12\x15\n\rdecided_at_ms\x18\n \x01(\x03\x12\r\n\x05stage\x18\x0b \x01(\t\x12\x1b\n\x13supersedes_chunk_id\x18\x0c \x01(\t\x12\x11\n\thit_count\x18\r \x01(\x05\x12\x15\n\rfirst_seen_ms\x18\x0e \x01(\x03\x12\x14\n\x0clast_seen_ms\x18\x0f \x01(\x03\x12\x0e\n\x06\x62inary\x18\x10 \x01(\t"f\n\x11\x44raftPolicyUpdate\x12\x15\n\rdraft_version\x18\x01 \x01(\x04\x12\x12\n\nnew_chunks\x18\x02 \x01(\r\x12\x15\n\rtotal_pending\x18\x03 \x01(\r\x12\x0f\n\x07summary\x18\x04 \x01(\t"\xa6\x01\n\x1bSubmitPolicyAnalysisRequest\x12.\n\tsummaries\x18\x01 \x03(\x0b\x32\x1b.openshell.v1.DenialSummary\x12\x32\n\x0fproposed_chunks\x18\x02 \x03(\x0b\x32\x19.openshell.v1.PolicyChunk\x12\x15\n\ranalysis_mode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t"k\n\x1cSubmitPolicyAnalysisResponse\x12\x17\n\x0f\x61\x63\x63\x65pted_chunks\x18\x01 \x01(\r\x12\x17\n\x0frejected_chunks\x18\x02 \x01(\r\x12\x19\n\x11rejection_reasons\x18\x03 \x03(\t"<\n\x15GetDraftPolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rstatus_filter\x18\x02 \x01(\t"\x90\x01\n\x16GetDraftPolicyResponse\x12)\n\x06\x63hunks\x18\x01 \x03(\x0b\x32\x19.openshell.v1.PolicyChunk\x12\x17\n\x0frolling_summary\x18\x02 \x01(\t\x12\x15\n\rdraft_version\x18\x03 \x01(\x04\x12\x1b\n\x13last_analyzed_at_ms\x18\x04 \x01(\x03":\n\x18\x41pproveDraftChunkRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63hunk_id\x18\x02 \x01(\t"H\n\x19\x41pproveDraftChunkResponse\x12\x16\n\x0epolicy_version\x18\x01 \x01(\r\x12\x13\n\x0bpolicy_hash\x18\x02 \x01(\t"I\n\x17RejectDraftChunkRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63hunk_id\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t"\x1a\n\x18RejectDraftChunkResponse"N\n\x1c\x41pproveAllDraftChunksRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18include_security_flagged\x18\x02 \x01(\x08"}\n\x1d\x41pproveAllDraftChunksResponse\x12\x16\n\x0epolicy_version\x18\x01 \x01(\r\x12\x13\n\x0bpolicy_hash\x18\x02 \x01(\t\x12\x17\n\x0f\x63hunks_approved\x18\x03 \x01(\r\x12\x16\n\x0e\x63hunks_skipped\x18\x04 \x01(\r"w\n\x15\x45\x64itDraftChunkRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63hunk_id\x18\x02 \x01(\t\x12>\n\rproposed_rule\x18\x03 \x01(\x0b\x32\'.openshell.sandbox.v1.NetworkPolicyRule"\x18\n\x16\x45\x64itDraftChunkResponse"7\n\x15UndoDraftChunkRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63hunk_id\x18\x02 \x01(\t"E\n\x16UndoDraftChunkResponse\x12\x16\n\x0epolicy_version\x18\x01 \x01(\r\x12\x13\n\x0bpolicy_hash\x18\x02 \x01(\t"\'\n\x17\x43learDraftChunksRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"2\n\x18\x43learDraftChunksResponse\x12\x16\n\x0e\x63hunks_cleared\x18\x01 \x01(\r"&\n\x16GetDraftHistoryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"d\n\x11\x44raftHistoryEntry\x12\x14\n\x0ctimestamp_ms\x18\x01 \x01(\x03\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x63hunk_id\x18\x04 \x01(\t"K\n\x17GetDraftHistoryResponse\x12\x30\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1f.openshell.v1.DraftHistoryEntry*\x9a\x01\n\x0cPolicyStatus\x12\x1d\n\x19POLICY_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15POLICY_STATUS_PENDING\x10\x01\x12\x18\n\x14POLICY_STATUS_LOADED\x10\x02\x12\x18\n\x14POLICY_STATUS_FAILED\x10\x03\x12\x1c\n\x18POLICY_STATUS_SUPERSEDED\x10\x04*\x86\x01\n\rServiceStatus\x12\x1e\n\x1aSERVICE_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERVICE_STATUS_HEALTHY\x10\x01\x12\x1b\n\x17SERVICE_STATUS_DEGRADED\x10\x02\x12\x1c\n\x18SERVICE_STATUS_UNHEALTHY\x10\x03\x32\xa1\x18\n\tOpenShell\x12\x43\n\x06Health\x12\x1b.openshell.v1.HealthRequest\x1a\x1c.openshell.v1.HealthResponse\x12R\n\rCreateSandbox\x12".openshell.v1.CreateSandboxRequest\x1a\x1d.openshell.v1.SandboxResponse\x12L\n\nGetSandbox\x12\x1f.openshell.v1.GetSandboxRequest\x1a\x1d.openshell.v1.SandboxResponse\x12X\n\rListSandboxes\x12".openshell.v1.ListSandboxesRequest\x1a#.openshell.v1.ListSandboxesResponse\x12X\n\rDeleteSandbox\x12".openshell.v1.DeleteSandboxRequest\x1a#.openshell.v1.DeleteSandboxResponse\x12\x61\n\x10\x43reateSshSession\x12%.openshell.v1.CreateSshSessionRequest\x1a&.openshell.v1.CreateSshSessionResponse\x12\x61\n\x10RevokeSshSession\x12%.openshell.v1.RevokeSshSessionRequest\x1a&.openshell.v1.RevokeSshSessionResponse\x12Q\n\x0b\x45xecSandbox\x12 .openshell.v1.ExecSandboxRequest\x1a\x1e.openshell.v1.ExecSandboxEvent0\x01\x12U\n\x0e\x43reateProvider\x12#.openshell.v1.CreateProviderRequest\x1a\x1e.openshell.v1.ProviderResponse\x12O\n\x0bGetProvider\x12 .openshell.v1.GetProviderRequest\x1a\x1e.openshell.v1.ProviderResponse\x12X\n\rListProviders\x12".openshell.v1.ListProvidersRequest\x1a#.openshell.v1.ListProvidersResponse\x12U\n\x0eUpdateProvider\x12#.openshell.v1.UpdateProviderRequest\x1a\x1e.openshell.v1.ProviderResponse\x12[\n\x0e\x44\x65leteProvider\x12#.openshell.v1.DeleteProviderRequest\x1a$.openshell.v1.DeleteProviderResponse\x12q\n\x10GetSandboxConfig\x12-.openshell.sandbox.v1.GetSandboxConfigRequest\x1a..openshell.sandbox.v1.GetSandboxConfigResponse\x12q\n\x10GetGatewayConfig\x12-.openshell.sandbox.v1.GetGatewayConfigRequest\x1a..openshell.sandbox.v1.GetGatewayConfigResponse\x12U\n\x0cUpdateConfig\x12!.openshell.v1.UpdateConfigRequest\x1a".openshell.v1.UpdateConfigResponse\x12s\n\x16GetSandboxPolicyStatus\x12+.openshell.v1.GetSandboxPolicyStatusRequest\x1a,.openshell.v1.GetSandboxPolicyStatusResponse\x12j\n\x13ListSandboxPolicies\x12(.openshell.v1.ListSandboxPoliciesRequest\x1a).openshell.v1.ListSandboxPoliciesResponse\x12g\n\x12ReportPolicyStatus\x12\'.openshell.v1.ReportPolicyStatusRequest\x1a(.openshell.v1.ReportPolicyStatusResponse\x12\x88\x01\n\x1dGetSandboxProviderEnvironment\x12\x32.openshell.v1.GetSandboxProviderEnvironmentRequest\x1a\x33.openshell.v1.GetSandboxProviderEnvironmentResponse\x12[\n\x0eGetSandboxLogs\x12#.openshell.v1.GetSandboxLogsRequest\x1a$.openshell.v1.GetSandboxLogsResponse\x12`\n\x0fPushSandboxLogs\x12$.openshell.v1.PushSandboxLogsRequest\x1a%.openshell.v1.PushSandboxLogsResponse(\x01\x12U\n\x0cWatchSandbox\x12!.openshell.v1.WatchSandboxRequest\x1a .openshell.v1.SandboxStreamEvent0\x01\x12m\n\x14SubmitPolicyAnalysis\x12).openshell.v1.SubmitPolicyAnalysisRequest\x1a*.openshell.v1.SubmitPolicyAnalysisResponse\x12[\n\x0eGetDraftPolicy\x12#.openshell.v1.GetDraftPolicyRequest\x1a$.openshell.v1.GetDraftPolicyResponse\x12\x64\n\x11\x41pproveDraftChunk\x12&.openshell.v1.ApproveDraftChunkRequest\x1a\'.openshell.v1.ApproveDraftChunkResponse\x12\x61\n\x10RejectDraftChunk\x12%.openshell.v1.RejectDraftChunkRequest\x1a&.openshell.v1.RejectDraftChunkResponse\x12p\n\x15\x41pproveAllDraftChunks\x12*.openshell.v1.ApproveAllDraftChunksRequest\x1a+.openshell.v1.ApproveAllDraftChunksResponse\x12[\n\x0e\x45\x64itDraftChunk\x12#.openshell.v1.EditDraftChunkRequest\x1a$.openshell.v1.EditDraftChunkResponse\x12[\n\x0eUndoDraftChunk\x12#.openshell.v1.UndoDraftChunkRequest\x1a$.openshell.v1.UndoDraftChunkResponse\x12\x61\n\x10\x43learDraftChunks\x12%.openshell.v1.ClearDraftChunksRequest\x1a&.openshell.v1.ClearDraftChunksResponse\x12^\n\x0fGetDraftHistory\x12$.openshell.v1.GetDraftHistoryRequest\x1a%.openshell.v1.GetDraftHistoryResponseB\x1e\n\x1a\x63om.anthropic.openshell.v1P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "openshell_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\n\032com.anthropic.openshell.v1P\001"
    _globals["_EXECSANDBOXREQUEST_ENVIRONMENTENTRY"]._loaded_options = None
    _globals["_EXECSANDBOXREQUEST_ENVIRONMENTENTRY"]._serialized_options = b"8\001"
    _globals["_SANDBOXLOGLINE_FIELDSENTRY"]._loaded_options = None
    _globals["_SANDBOXLOGLINE_FIELDSENTRY"]._serialized_options = b"8\001"
    _globals["_PLATFORMEVENT_METADATAENTRY"]._loaded_options = None
    _globals["_PLATFORMEVENT_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_GETSANDBOXPROVIDERENVIRONMENTRESPONSE_ENVIRONMENTENTRY"]._loaded_options = None
    _globals[
        "_GETSANDBOXPROVIDERENVIRONMENTRESPONSE_ENVIRONMENTENTRY"
    ]._serialized_options = b"8\001"
    _globals["_POLICYSTATUS"]._serialized_start = 7217
    _globals["_POLICYSTATUS"]._serialized_end = 7371
    _globals["_SERVICESTATUS"]._serialized_start = 7374
    _globals["_SERVICESTATUS"]._serialized_end = 7508
    _globals["_HEALTHREQUEST"]._serialized_start = 65
    _globals["_HEALTHREQUEST"]._serialized_end = 80
    _globals["_HEALTHRESPONSE"]._serialized_start = 82
    _globals["_HEALTHRESPONSE"]._serialized_end = 160
    _globals["_CREATESANDBOXREQUEST"]._serialized_start = 162
    _globals["_CREATESANDBOXREQUEST"]._serialized_end = 249
    _globals["_GETSANDBOXREQUEST"]._serialized_start = 251
    _globals["_GETSANDBOXREQUEST"]._serialized_end = 284
    _globals["_LISTSANDBOXESREQUEST"]._serialized_start = 286
    _globals["_LISTSANDBOXESREQUEST"]._serialized_end = 339
    _globals["_DELETESANDBOXREQUEST"]._serialized_start = 341
    _globals["_DELETESANDBOXREQUEST"]._serialized_end = 377
    _globals["_SANDBOXRESPONSE"]._serialized_start = 379
    _globals["_SANDBOXRESPONSE"]._serialized_end = 446
    _globals["_LISTSANDBOXESRESPONSE"]._serialized_start = 448
    _globals["_LISTSANDBOXESRESPONSE"]._serialized_end = 523
    _globals["_DELETESANDBOXRESPONSE"]._serialized_start = 525
    _globals["_DELETESANDBOXRESPONSE"]._serialized_end = 565
    _globals["_CREATESSHSESSIONREQUEST"]._serialized_start = 567
    _globals["_CREATESSHSESSIONREQUEST"]._serialized_end = 612
    _globals["_CREATESSHSESSIONRESPONSE"]._serialized_start = 615
    _globals["_CREATESSHSESSIONRESPONSE"]._serialized_end = 819
    _globals["_REVOKESSHSESSIONREQUEST"]._serialized_start = 821
    _globals["_REVOKESSHSESSIONREQUEST"]._serialized_end = 861
    _globals["_REVOKESSHSESSIONRESPONSE"]._serialized_start = 863
    _globals["_REVOKESSHSESSIONRESPONSE"]._serialized_end = 906
    _globals["_EXECSANDBOXREQUEST"]._serialized_start = 909
    _globals["_EXECSANDBOXREQUEST"]._serialized_end = 1147
    _globals["_EXECSANDBOXREQUEST_ENVIRONMENTENTRY"]._serialized_start = 1097
    _globals["_EXECSANDBOXREQUEST_ENVIRONMENTENTRY"]._serialized_end = 1147
    _globals["_EXECSANDBOXSTDOUT"]._serialized_start = 1149
    _globals["_EXECSANDBOXSTDOUT"]._serialized_end = 1182
    _globals["_EXECSANDBOXSTDERR"]._serialized_start = 1184
    _globals["_EXECSANDBOXSTDERR"]._serialized_end = 1217
    _globals["_EXECSANDBOXEXIT"]._serialized_start = 1219
    _globals["_EXECSANDBOXEXIT"]._serialized_end = 1255
    _globals["_EXECSANDBOXEVENT"]._serialized_start = 1258
    _globals["_EXECSANDBOXEVENT"]._serialized_end = 1436
    _globals["_SSHSESSION"]._serialized_start = 1439
    _globals["_SSHSESSION"]._serialized_end = 1575
    _globals["_WATCHSANDBOXREQUEST"]._serialized_start = 1578
    _globals["_WATCHSANDBOXREQUEST"]._serialized_end = 1814
    _globals["_SANDBOXSTREAMEVENT"]._serialized_start = 1817
    _globals["_SANDBOXSTREAMEVENT"]._serialized_end = 2110
    _globals["_SANDBOXLOGLINE"]._serialized_start = 2113
    _globals["_SANDBOXLOGLINE"]._serialized_end = 2340
    _globals["_SANDBOXLOGLINE_FIELDSENTRY"]._serialized_start = 2295
    _globals["_SANDBOXLOGLINE_FIELDSENTRY"]._serialized_end = 2340
    _globals["_PLATFORMEVENT"]._serialized_start = 2343
    _globals["_PLATFORMEVENT"]._serialized_end = 2553
    _globals["_PLATFORMEVENT_METADATAENTRY"]._serialized_start = 2506
    _globals["_PLATFORMEVENT_METADATAENTRY"]._serialized_end = 2553
    _globals["_SANDBOXSTREAMWARNING"]._serialized_start = 2555
    _globals["_SANDBOXSTREAMWARNING"]._serialized_end = 2594
    _globals["_CREATEPROVIDERREQUEST"]._serialized_start = 2596
    _globals["_CREATEPROVIDERREQUEST"]._serialized_end = 2671
    _globals["_GETPROVIDERREQUEST"]._serialized_start = 2673
    _globals["_GETPROVIDERREQUEST"]._serialized_end = 2707
    _globals["_LISTPROVIDERSREQUEST"]._serialized_start = 2709
    _globals["_LISTPROVIDERSREQUEST"]._serialized_end = 2762
    _globals["_UPDATEPROVIDERREQUEST"]._serialized_start = 2764
    _globals["_UPDATEPROVIDERREQUEST"]._serialized_end = 2839
    _globals["_DELETEPROVIDERREQUEST"]._serialized_start = 2841
    _globals["_DELETEPROVIDERREQUEST"]._serialized_end = 2878
    _globals["_PROVIDERRESPONSE"]._serialized_start = 2880
    _globals["_PROVIDERRESPONSE"]._serialized_end = 2950
    _globals["_LISTPROVIDERSRESPONSE"]._serialized_start = 2952
    _globals["_LISTPROVIDERSRESPONSE"]._serialized_end = 3028
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_start = 3030
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_end = 3071
    _globals["_GETSANDBOXPROVIDERENVIRONMENTREQUEST"]._serialized_start = 3073
    _globals["_GETSANDBOXPROVIDERENVIRONMENTREQUEST"]._serialized_end = 3131
    _globals["_GETSANDBOXPROVIDERENVIRONMENTRESPONSE"]._serialized_start = 3134
    _globals["_GETSANDBOXPROVIDERENVIRONMENTRESPONSE"]._serialized_end = 3316
    _globals["_GETSANDBOXPROVIDERENVIRONMENTRESPONSE_ENVIRONMENTENTRY"]._serialized_start = 1097
    _globals["_GETSANDBOXPROVIDERENVIRONMENTRESPONSE_ENVIRONMENTENTRY"]._serialized_end = 1147
    _globals["_UPDATECONFIGREQUEST"]._serialized_start = 3319
    _globals["_UPDATECONFIGREQUEST"]._serialized_end = 3527
    _globals["_UPDATECONFIGRESPONSE"]._serialized_start = 3529
    _globals["_UPDATECONFIGRESPONSE"]._serialized_end = 3633
    _globals["_GETSANDBOXPOLICYSTATUSREQUEST"]._serialized_start = 3635
    _globals["_GETSANDBOXPOLICYSTATUSREQUEST"]._serialized_end = 3713
    _globals["_GETSANDBOXPOLICYSTATUSRESPONSE"]._serialized_start = 3715
    _globals["_GETSANDBOXPOLICYSTATUSRESPONSE"]._serialized_end = 3826
    _globals["_LISTSANDBOXPOLICIESREQUEST"]._serialized_start = 3828
    _globals["_LISTSANDBOXPOLICIESREQUEST"]._serialized_end = 3917
    _globals["_LISTSANDBOXPOLICIESRESPONSE"]._serialized_start = 3919
    _globals["_LISTSANDBOXPOLICIESRESPONSE"]._serialized_end = 4004
    _globals["_REPORTPOLICYSTATUSREQUEST"]._serialized_start = 4007
    _globals["_REPORTPOLICYSTATUSREQUEST"]._serialized_end = 4135
    _globals["_REPORTPOLICYSTATUSRESPONSE"]._serialized_start = 4137
    _globals["_REPORTPOLICYSTATUSRESPONSE"]._serialized_end = 4165
    _globals["_SANDBOXPOLICYREVISION"]._serialized_start = 4168
    _globals["_SANDBOXPOLICYREVISION"]._serialized_end = 4391
    _globals["_GETSANDBOXLOGSREQUEST"]._serialized_start = 4393
    _globals["_GETSANDBOXLOGSREQUEST"]._serialized_end = 4505
    _globals["_PUSHSANDBOXLOGSREQUEST"]._serialized_start = 4507
    _globals["_PUSHSANDBOXLOGSREQUEST"]._serialized_end = 4595
    _globals["_PUSHSANDBOXLOGSRESPONSE"]._serialized_start = 4597
    _globals["_PUSHSANDBOXLOGSRESPONSE"]._serialized_end = 4622
    _globals["_GETSANDBOXLOGSRESPONSE"]._serialized_start = 4624
    _globals["_GETSANDBOXLOGSRESPONSE"]._serialized_end = 4714
    _globals["_L7REQUESTSAMPLE"]._serialized_start = 4716
    _globals["_L7REQUESTSAMPLE"]._serialized_end = 4796
    _globals["_DENIALSUMMARY"]._serialized_start = 4799
    _globals["_DENIALSUMMARY"]._serialized_end = 5204
    _globals["_POLICYCHUNK"]._serialized_start = 5207
    _globals["_POLICYCHUNK"]._serialized_end = 5592
    _globals["_DRAFTPOLICYUPDATE"]._serialized_start = 5594
    _globals["_DRAFTPOLICYUPDATE"]._serialized_end = 5696
    _globals["_SUBMITPOLICYANALYSISREQUEST"]._serialized_start = 5699
    _globals["_SUBMITPOLICYANALYSISREQUEST"]._serialized_end = 5865
    _globals["_SUBMITPOLICYANALYSISRESPONSE"]._serialized_start = 5867
    _globals["_SUBMITPOLICYANALYSISRESPONSE"]._serialized_end = 5974
    _globals["_GETDRAFTPOLICYREQUEST"]._serialized_start = 5976
    _globals["_GETDRAFTPOLICYREQUEST"]._serialized_end = 6036
    _globals["_GETDRAFTPOLICYRESPONSE"]._serialized_start = 6039
    _globals["_GETDRAFTPOLICYRESPONSE"]._serialized_end = 6183
    _globals["_APPROVEDRAFTCHUNKREQUEST"]._serialized_start = 6185
    _globals["_APPROVEDRAFTCHUNKREQUEST"]._serialized_end = 6243
    _globals["_APPROVEDRAFTCHUNKRESPONSE"]._serialized_start = 6245
    _globals["_APPROVEDRAFTCHUNKRESPONSE"]._serialized_end = 6317
    _globals["_REJECTDRAFTCHUNKREQUEST"]._serialized_start = 6319
    _globals["_REJECTDRAFTCHUNKREQUEST"]._serialized_end = 6392
    _globals["_REJECTDRAFTCHUNKRESPONSE"]._serialized_start = 6394
    _globals["_REJECTDRAFTCHUNKRESPONSE"]._serialized_end = 6420
    _globals["_APPROVEALLDRAFTCHUNKSREQUEST"]._serialized_start = 6422
    _globals["_APPROVEALLDRAFTCHUNKSREQUEST"]._serialized_end = 6500
    _globals["_APPROVEALLDRAFTCHUNKSRESPONSE"]._serialized_start = 6502
    _globals["_APPROVEALLDRAFTCHUNKSRESPONSE"]._serialized_end = 6627
    _globals["_EDITDRAFTCHUNKREQUEST"]._serialized_start = 6629
    _globals["_EDITDRAFTCHUNKREQUEST"]._serialized_end = 6748
    _globals["_EDITDRAFTCHUNKRESPONSE"]._serialized_start = 6750
    _globals["_EDITDRAFTCHUNKRESPONSE"]._serialized_end = 6774
    _globals["_UNDODRAFTCHUNKREQUEST"]._serialized_start = 6776
    _globals["_UNDODRAFTCHUNKREQUEST"]._serialized_end = 6831
    _globals["_UNDODRAFTCHUNKRESPONSE"]._serialized_start = 6833
    _globals["_UNDODRAFTCHUNKRESPONSE"]._serialized_end = 6902
    _globals["_CLEARDRAFTCHUNKSREQUEST"]._serialized_start = 6904
    _globals["_CLEARDRAFTCHUNKSREQUEST"]._serialized_end = 6943
    _globals["_CLEARDRAFTCHUNKSRESPONSE"]._serialized_start = 6945
    _globals["_CLEARDRAFTCHUNKSRESPONSE"]._serialized_end = 6995
    _globals["_GETDRAFTHISTORYREQUEST"]._serialized_start = 6997
    _globals["_GETDRAFTHISTORYREQUEST"]._serialized_end = 7035
    _globals["_DRAFTHISTORYENTRY"]._serialized_start = 7037
    _globals["_DRAFTHISTORYENTRY"]._serialized_end = 7137
    _globals["_GETDRAFTHISTORYRESPONSE"]._serialized_start = 7139
    _globals["_GETDRAFTHISTORYRESPONSE"]._serialized_end = 7214
    _globals["_OPENSHELL"]._serialized_start = 7511
    _globals["_OPENSHELL"]._serialized_end = 10616
# @@protoc_insertion_point(module_scope)
