<div class="modal fade" id="approvalModal" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header border-0">
                <h5 class="modal-title"><i class="bi bi-shield-exclamation text-warning me-2"></i>Access Request</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body text-center py-4">
                <div id="approval-icon" class="mb-3"><i class="bi bi-globe2 fs-1 text-primary"></i></div>
                <p id="approval-message" class="fs-5 mb-1"></p>
                <p id="approval-detail" class="text-muted small"></p>
                <div id="approval-security" class="alert alert-warning small mt-3" style="display:none"></div>
            </div>
            <div class="modal-footer border-0 justify-content-center gap-2">
                <button type="button" class="btn btn-outline-success" id="btn-approve-once"><i class="bi bi-check me-1"></i>Allow Once</button>
                <button type="button" class="btn btn-success" id="btn-approve-always"><i class="bi bi-check-all me-1"></i>Always Allow</button>
                <button type="button" class="btn btn-outline-danger" id="btn-reject"><i class="bi bi-x me-1"></i>Deny</button>
            </div>
        </div>
    </div>
</div>
